@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-editable-toolbar.h,v 1.4 2005/06/17 11:00:23 marco Exp $
+ *  $Id: egg-editable-toolbar.h,v 1.7 2006/05/26 06:45:19 nshmyrev Exp $
  */
 
 #ifndef EGG_EDITABLE_TOOLBAR_H
@@ -29,6 +29,7 @@
 #include <gtk/gtkvbox.h>
 #include <gtk/gtktoolitem.h>
 #include <gtk/gtktoolbar.h>
+#include <gtk/gtkmenu.h>
 
 G_BEGIN_DECLS
 
@@ -60,12 +61,15 @@ struct _EggEditableToolbarClass
 };
 
 GType               egg_editable_toolbar_get_type        (void);
-GtkWidget	   *egg_editable_toolbar_new		 (GtkUIManager         *manager);
+GtkWidget	   *egg_editable_toolbar_new		 (GtkUIManager         *manager,
+							  const char           *visibility_path);
 GtkWidget	   *egg_editable_toolbar_new_with_model	 (GtkUIManager         *manager,
-							  EggToolbarsModel     *model);
+							  EggToolbarsModel     *model,
+							  const char           *visibility_path);
 void		    egg_editable_toolbar_set_model       (EggEditableToolbar   *etoolbar,
 							  EggToolbarsModel     *model);
 EggToolbarsModel   *egg_editable_toolbar_get_model       (EggEditableToolbar   *etoolbar);
+GtkUIManager       *egg_editable_toolbar_get_manager     (EggEditableToolbar   *etoolbar);
 void		    egg_editable_toolbar_set_edit_mode	 (EggEditableToolbar   *etoolbar,
 							  gboolean              mode);
 gboolean	    egg_editable_toolbar_get_edit_mode	 (EggEditableToolbar   *etoolbar);
@@ -73,13 +77,15 @@ void		    egg_editable_toolbar_show		 (EggEditableToolbar   *etoolbar,
 							  const char           *name);
 void		    egg_editable_toolbar_hide		 (EggEditableToolbar   *etoolbar,
 							  const char           *name);
-void		    egg_editable_toolbar_set_drag_dest   (EggEditableToolbar   *etoolbar,
-							  const GtkTargetEntry *targets,
-							  gint                  n_targets,
-							  const char           *toolbar_name);
 void		    egg_editable_toolbar_set_fixed       (EggEditableToolbar   *etoolbar,
 							  GtkToolbar           *fixed_toolbar);
 
+GtkWidget *         egg_editable_toolbar_get_selected    (EggEditableToolbar   *etoolbar);
+void                egg_editable_toolbar_set_selected    (EggEditableToolbar   *etoolbar,
+							  GtkWidget            *widget);
+
+void              egg_editable_toolbar_add_visibility    (EggEditableToolbar   *etoolbar,
+							  const char           *path);
 
 /* Private Functions */
 
